% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rbms_index_modelling.r
\name{flight_curve}
\alias{flight_curve}
\title{flight_curve
Compute the annual flight curve from butterfly count data collated across sites.}
\usage{
flight_curve(
  ts_season_count,
  NbrSample = 100,
  MinVisit = 3,
  MinOccur = 2,
  MinNbrSite = 1,
  MaxTrial = 3,
  GamFamily = "poisson",
  CompltSeason = TRUE,
  SelectYear = NULL,
  SpeedGam = TRUE,
  OptiGam = TRUE,
  KeepModel = TRUE,
  KeepModelData = TRUE,
  TimeUnit = "d",
  MultiVisit = "mean",
  weekday = 3,
  mod_form = NULL,
  tp_col = NULL,
  verbose = TRUE,
  ...
)
}
\arguments{
\item{ts_season_count}{data.table Time-series of counts and season information returned by \link{ts_monit_count_site}}

\item{NbrSample}{integer The maximum number of sites to use for computing the flight curve, default=100.}

\item{MinVisit}{integer The minimum number of visits required for a site to be included, default=3.}

\item{MinOccur}{integer The minimum number of positive records (e.g. >= 1) required in one year for a site to be included, default=2.}

\item{MinNbrSite}{integer The minimum number of sites required to compute a flight curve, default=1.}

\item{MaxTrial}{integer The maximum number of trials for model convergence, default=3.}

\item{GamFamily}{string The distribution of the error term used in the GAM, default='poisson', but can be the negative-binomial 'nb' or 'quasipoisson'.}

\item{CompltSeason}{Logical to restrict computation of flight curve for years where the complete season has been sampled, default=TRUE.}

\item{SelectYear}{integer Select a specific year to compute the flight curve, default=NULL.}

\item{SpeedGam}{Logical Set if the \link[mgcv]{bam} method should be used, default instead of the default \link[mgcv]{gam} method.}

\item{OptiGam}{Logical Set the use of the \link[mgcv]{bam} method when data are larger than 200 and gam for smaller datasets}

\item{KeepModel}{Logical to keep model output in a list object named \code{flight_curve_model}.}

\item{KeepModelData}{Logical to keep the data used for the GAM.}

\item{TimeUnit}{character The time-step for which the spline should be computed, 'd' day or 'w' week.}

\item{MultiVisit}{string Function to apply for summarising multiple counts within a time unit, 'max' or 'mean' (default).}

\item{weekday}{Integer for selected day of the week for weekly summary, default is 3 (Wednesday). [1-7] where 1 = Monday.}

\item{mod_form}{string with formula to be passed to the gam model, default null.}

\item{tp_col}{string or vector of string with additional variable used in the gam model, default null.}

\item{verbose}{a logical indicating if some “progress report” should be given.}

\item{...}{Additional parameters passed to gam or bam function from the \link[mgcv]{gam} package.}
}
\value{
A list with three objects, i) **pheno**: a vector with annual flight curves \code{f_pheno} with expected relative abundance, normalize to sum to one over a full season,
        ii) **model**: a list of the resulting gam models \code{f_model} fitted on the count data for each year and iii) **data**: a data.table with the data used to fit the GAM model.
}
\description{
flight_curve
Compute the annual flight curve from butterfly count data collated across sites.
}
\seealso{
\link{fit_gam}

\link[mgcv]{gam}

\link[mgcv]{bam}
}
\author{
Reto Schmucki - \email{reto.schmucki@mail.mcgill.ca}
}
\keyword{curve}
\keyword{flight}
\keyword{gam,}
